@@ -268,7 +268,9 @@ class FilenameOps(RPathTest):
         b"a////b//c": b"a/b/c",
         b"..": b"..",
         b"a/": b"a",
-        b"/a//b///": b"/a/b"
+        b"/a//b///": b"/a/b",
+        b"//host/share": b"//host/share",
+        b"//host//share/": b"//host/share",
     }
     dirsplitdict = {
         b"/": (b"", b""),
@@ -276,7 +278,8 @@ class FilenameOps(RPathTest):
         b"/a/b": (b"/a", b"b"),
         b".": (b".", b"."),
         b"b/c": (b"b", b"c"),
-        b"a": (b".", b"a")
+        b"a": (b".", b"a"),
+        b"//host/share": (b"//host", b"share"),
     }
 
     def testQuote(self):
@@ -309,12 +312,12 @@ class FilenameOps(RPathTest):
         """Test getting file numbers"""
         if (os.path.exists(b'/dev/sda')):
             devnums = rpath.RPath(self.lc, b"/dev/sda", ()).getdevnums()
-            assert devnums == (8, 0), devnums
+            self.assertEqual(devnums, ('b', 8, 0))
         else:
             devnums = rpath.RPath(self.lc, b"/dev/nvme0n1", ()).getdevnums()
-            assert devnums == (259, 0), devnums
+            self.assertEqual(devnums, ('b', 259, 0))
         devnums = rpath.RPath(self.lc, b"/dev/tty2", ()).getdevnums()
-        assert devnums == (4, 2), devnums
+        self.assertEqual(devnums, ('c', 4, 2))
 
 
 class FileIO(RPathTest):
