@@ -202,21 +202,27 @@ rdiff-backup_testfiles/select/1/1
 
     def testGlobRE(self):
         """testGlobRE - test translation of shell pattern to regular exp"""
-        # we can use str as input because glob_to_re works for bytes and str
-        # but always returns bytes.
-        assert self.Select.glob_to_re("hello") == b"hello"
-        assert self.Select.glob_to_re(".e?ll**o") == b"\\.e[^/]ll.*o"
-        r = self.Select.glob_to_re("[abc]el[^de][!fg]h")
-        assert r == b"[abc]el[^de][^fg]h", r
-        r = self.Select.glob_to_re("/usr/*/bin/")
+
+        def cmp_glob_to_re(src_glob, ref_re, old_ref_re=None, ver_limit=(3, 7)):
+            """Helper function to compare a glob and the resulting regexp"""
+            res_re = self.Select.glob_to_re(os.fsencode(src_glob))
+            # in case something has changed between Python versions
+            if old_ref_re and sys.version_info < ver_limit:
+                ref_re = old_ref_re
+            self.assertEqual(res_re, ref_re,
+                             "Regexp '%s' from '%s' doesn't equal to %s" % (
+                                 res_re, src_glob, ref_re))
+
+        cmp_glob_to_re("hello", b"hello")
+        cmp_glob_to_re(".e?ll**o", b"\\.e[^/]ll.*o")
         # since Python 3.7 only characters special to reg expr are quoted
-        if (sys.version_info >= (3, 7)):
-            assert r == b"/usr/[^/]*/bin/", r
-        else:
-            assert r == b"\\/usr\\/[^/]*\\/bin\\/", r
-        assert self.Select.glob_to_re("[a.b/c]") == b"[a.b/c]"
-        r = self.Select.glob_to_re("[a*b-c]e[!]]")
-        assert r == b"[a*b-c]e[^]]", r
+        # it seems that also non-ASCII characters were quoted before
+        cmp_glob_to_re("*/é", os.fsencode("[^/]*/é"), os.fsencode("[^/]*\\/\\é"))
+        cmp_glob_to_re("[abc]el[^de][!fg]h", b"[abc]el[^de][^fg]h")
+        # since Python 3.7 only characters special to reg expr are quoted
+        cmp_glob_to_re("/usr/*/bin/", b"/usr/[^/]*/bin/", b"\\/usr\\/[^/]*\\/bin\\/")
+        cmp_glob_to_re("[a.b/c]", b"[a.b/c]")
+        cmp_glob_to_re("[a*b-c]e[!]]", b"[a*b-c]e[^]]")
 
     def testGlobSFException(self):
         """testGlobSFException - see if globbing errors returned"""
@@ -375,6 +381,19 @@ class ParseArgsTest(unittest.TestCase):
 rdiff-backup_testfiles/select/1/1
 - rdiff-backup_testfiles/select/1
 - **
+"""])
+
+    def test_globbing_filelist_winending(self):
+        """Filelist glob test with Windows/DOS endings"""
+        # the \r's are used to test Windows/DOS endings
+        self.ParseTest([("--include-globbing-filelist", "file")],
+                       [(), ('1', ), ('1', '1'), ('1', '1', '2'),
+                        ('1', '1', '3')], [
+                            """
+- rdiff-backup_testfiles/select/1/1/1\r
+rdiff-backup_testfiles/select/1/1\r
+- rdiff-backup_testfiles/select/1\r
+- **\r
 """])
 
     def testGlob(self):
